import { Component, OnInit, Input, OnChanges, AfterContentInit } from '@angular/core';
import { Router } from '@angular/router';
import { Target } from 'packages/target/model';

import { Store, select } from '@ngrx/store';
import { RPCError } from 'packages/core/rpc/error';
import * as ListStore from 'packages/meta/crawler/store/list';
import { ReadAllCrawlerSelector } from 'packages/meta/crawler/store';
import { MetaCrawler } from 'packages/meta/crawler/model/MetaCrawler';


@Component({
  selector: 'of-crawler-selector',
  templateUrl: './crawler-selector.component.html',
  styleUrls: ['./crawler-selector.component.scss']
})
export class CrawlerSelectorComponent implements OnInit, OnChanges, AfterContentInit {

  crawlers$ = this.listStore.pipe(select(ReadAllCrawlerSelector.select('list')));

  @Input() selectedTarget: Target;
  crawlers: MetaCrawler[];

  constructor(
    private router: Router,
    private listStore: Store<ListStore.State>,
  ) {}

  ngOnInit() {
    this.crawlers$.subscribe(
      (list: MetaCrawler[]) => {
        if (list !== null) {
          console.log(list);
        }
      },
      (error: RPCError) => {
        console.log(error.response.message);
      }
    );
  }

  ngAfterContentInit() {
    this.listStore.dispatch(new ListStore.ReadAll());
  }

  ngOnChanges() {
    if (this.selectedTarget) {
      console.log('Getting valid crawlers for ' + this.selectedTarget.displayName);
    }

    this.crawlers = new Array();
    for (let i = 0; i < 3; i++) {
      const c: MetaCrawler = {
        id: i,
        name: 'Crawler' + i,
      };
      this.crawlers.push(c);
    }
  }

  crawlerSelected(crawler: MetaCrawler) {
    // console.log(crawler);
  }
}
